@@ -250,7 +250,7 @@ def _platform_edit(
     ext = os.path.splitext(source_path)[1]
     if ext == ".c":
         fmt = '#line 1 "box {}"\n'
-    elif ext == ".s":
+    elif ext == ".s" or ext == ".S":
         # I can't get this to work in the `gnu assembler <https://gcc.gnu.org/onlinedocs/cpp/Line-Control.html>`_. I tried:
         #
         # - From Section 4.11 (Misc directives):
@@ -276,6 +276,9 @@ def _platform_edit(
     elif ext == ".rs":
         # Rust doesn't support `setting line numbers <https://github.com/rust-lang/rfcs/issues/1862>`__ either.
         fmt = ""
+    elif ext == ".v":
+        # Quoting from section 19.7 of the IEEE Standard for Verilog Hardware Description Language (IEEE Std 1364-2005), the syntax for this compiler directive is ```line number "filename" level``, where ``level == 0`` indicates that this line doesn't precede or follow an include directive.
+        fmt = '`line 1 "box {}" 0\n'
     else:
         # This is an unsupported language. It would be nice to report this as an error instead of raising an exception.
         raise RuntimeError("Unsupported extension {}".format(ext))
